<?php
/**
 * Drag & Drop Sections
 *
 * @package Lifestyle Magazine
 */
add_action( 'customize_register', 'lifestyle_magazine_drag_and_drop_sections' );

function lifestyle_magazine_drag_and_drop_sections( $wp_customize ) {

	$wp_customize->add_section( 'lifestyle_magazine_sort_homepage_sections', array(
		'title'       => esc_html__( 'Drag & Drop', 'lifestyle-magazine' ),
		'description' => esc_html__( 'Drag & Drop', 'lifestyle-magazine' ),
		'panel'       => 'lifestyle_magazine_theme_options_panel',
	) );

	$default = array( 'main-page', 'slider', 'pages', 'featured', 'blog-list', 'category-display' );

	$choices = array(
		'main-page'        => esc_html__( 'Main Section', 'lifestyle-magazine' ),
		'slider'           => esc_html__( 'Slider Section', 'lifestyle-magazine' ),
		'pages'            => esc_html__( 'Pages Section', 'lifestyle-magazine' ),
		'featured'         => esc_html__( 'Featured Section', 'lifestyle-magazine' ),
		'blog-list'        => esc_html__( 'Blog List Section', 'lifestyle-magazine' ),
		'category-display' => esc_html__( 'Category Display Section', 'lifestyle-magazine' ),
	);


	$wp_customize->add_setting( 'lifestyle_magazine_sort_homepage', array(
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'lifestyle_magazine_sanitize_array',
		'default'           => $default
	) );

	$wp_customize->add_control( new Lifestyle_Magazine_Control_Sortable( $wp_customize, 'lifestyle_magazine_sort_homepage', array(
		'label'    => esc_html__( 'Drag and Drop Sections to rearrange.', 'lifestyle-magazine' ),
		'section'  => 'lifestyle_magazine_sort_homepage_sections',
		'settings' => 'lifestyle_magazine_sort_homepage',
		'type'     => 'sortable',
		'disabled' => lmp_fs()->is_free_plan(),
		'choices'  => $choices
	) ) );

	if ( lmp_fs()->is_free_plan() ) {
    $wp_customize->add_setting( 'lifestyle_magazine_sort_homepage_upgrade_to_pro', array(
        'sanitize_callback' => null,
    ) );
    $wp_customize->add_control( new Lifestyle_Magazine_Control_Upgrade_To_Pro(
      $wp_customize, 'lifestyle_magazine_sort_homepage_upgrade_to_pro', array(
        'section' => 'lifestyle_magazine_sort_homepage_sections',
        'settings'    => 'lifestyle_magazine_sort_homepage_upgrade_to_pro',
        'title'   => __( 'Rearrange homepage sections and prioritize what your visitors should see first.', 'lifestyle-magazine' ),
        'items' => array(
            'one'   => array(
                'title' => __( 'Rearrange sections on the Homepage', 'lifestyle-magazine' ),
            ),
        ),
        'button_url'   => esc_url( 'https://thebootstrapthemes.com/lifestyle-magazine/#free-vs-pro' ),
        'button_text'   => __( 'Upgrade Now', 'lifestyle-magazine' ),
      )
    ) );
	}

}